Managers
========

.. currentmodule:: npap.managers

The manager classes orchestrate the partitioning and aggregation workflow.

PartitionAggregatorManager
--------------------------

.. autoclass:: PartitionAggregatorManager
   :show-inheritance:
   :no-index:

   See :class:`npap.PartitionAggregatorManager` for full member documentation.

InputDataManager
----------------

.. autoclass:: InputDataManager
   :members:
   :show-inheritance:

PartitioningManager
-------------------

.. autoclass:: PartitioningManager
   :members:
   :show-inheritance:

AggregationManager
------------------

.. autoclass:: AggregationManager
   :members:
   :show-inheritance:
